@@ -1,14 +1,13 @@
 package Bot::IRC::X::Message;
 # ABSTRACT: Bot::IRC plugin for leaving messages for nicks
 
-use 5.012;
-use strict;
-use warnings;
+use 5.014;
+use exact;
 
 use DateTime;
 use DateTime::Format::Human::Duration;
 
-our $VERSION = '1.03'; # VERSION
+our $VERSION = '1.04'; # VERSION
 
 sub init {
     my ($bot) = @_;
@@ -81,10 +80,10 @@ Bot::IRC::X::Message - Bot::IRC plugin for leaving messages for nicks
 
 =head1 VERSION
 
-version 1.03
+version 1.04
 
-=for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Bot-IRC-X-Message.svg)](https://travis-ci.org/gryphonshafer/Bot-IRC-X-Message)
-[![Coverage Status](https://coveralls.io/repos/gryphonshafer/Bot-IRC-X-Message/badge.png)](https://coveralls.io/r/gryphonshafer/Bot-IRC-X-Message)
+=for markdown [![test](https://github.com/gryphonshafer/Bot-IRC-X-Message/workflows/test/badge.svg)](https://github.com/gryphonshafer/Bot-IRC-X-Message/actions?query=workflow%3Atest)
+[![codecov](https://codecov.io/gh/gryphonshafer/Bot-IRC-X-Message/graph/badge.svg)](https://codecov.io/gh/gryphonshafer/Bot-IRC-X-Message)
 
 =head1 SYNOPSIS
 
@@ -121,23 +120,15 @@ L<GitHub|https://github.com/gryphonshafer/Bot-IRC-X-Message>
 
 =item *
 
-L<CPAN|http://search.cpan.org/dist/Bot-IRC-X-Message>
-
-=item *
-
 L<MetaCPAN|https://metacpan.org/pod/Bot::IRC::X::Message>
 
 =item *
 
-L<AnnoCPAN|http://annocpan.org/dist/Bot-IRC-X-Message>
+L<GitHub Actions|https://github.com/gryphonshafer/Bot-IRC-X-Message/actions>
 
 =item *
 
-L<Travis CI|https://travis-ci.org/gryphonshafer/Bot-IRC-X-Message>
-
-=item *
-
-L<Coveralls|https://coveralls.io/r/gryphonshafer/Bot-IRC-X-Message>
+L<Codecov|https://codecov.io/gh/gryphonshafer/Bot-IRC-X-Message>
 
 =item *
 
@@ -157,9 +148,10 @@ Gryphon Shafer <gryphon@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Gryphon Shafer.
+This software is Copyright (c) 2016-2021 by Gryphon Shafer.
 
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
+This is free software, licensed under:
+
+  The Artistic License 2.0 (GPL Compatible)
 
 =cut
